h1,h2 {
    color: #00bbd7;
}

table {
    border-collapse: collapse;
    width: 800;
}

th, td {
    padding: 6px;
    text-align: left;
    border-bottom: 1px solid #ddd;
}
th {
    background: #00bbd7;
    color: white;
}


a:link {
    text-decoration: none;
    color: #00bbd7;
}

a:visited {
    text-decoration: none;
    color: #00bbd7;
}

a:hover {
    text-decoration: underline;
}

a:active {
    text-decoration: underline;
}
