:root {
    --color1: #00bbd7;
    --color2: #777;
    --color3: #ff005f;
    --color4: #eef;
    --menu_bg: #333;
    --menu_bg_hover: #777;
}


@font-face {
  font-family: "Encode Regular";
  src: url("/static/fonts/EncodeSans-Regular.ttf") format('truetype');
}


/*===========================================================================*/
/* Default Elements                                                          */
/*===========================================================================*/

body {
    margin:0;
    font: 15px "Encode Regular";
}

pre {
    background-color: #eee;
    overflow-x:auto;
}

table {
    border-collapse: collapse;
    width: 800;
}

th, td {
    padding: 6px;
    text-align: left;
    border-bottom: 1px solid var(--color2);
}

th {
    background: var(--color1);
    color: white;
}

a {
    text-decoration: none;
}



/*===========================================================================*/
/* TOP Menu                                                                  */
/*===========================================================================*/
ul.menu {
    list-style-type: none;
    margin: 0;
    padding: 0;
    overflow: hidden;
    background-color: var(--menu_bg);
    position: fixed; /* Set the navbar to fixed position */
    top: 0; /* Position the navbar at the top of the page */
    width: 100%; /* Full width */
    /* box-shadow: 0px 4px 4px #aaaaaa; */
    z-index: 1;
}

ul.menu li {
    float: left;
}

ul.menu li a {
    display: block;
    color: white;
    padding: 10px;
    text-decoration: none;
    transition: all 0.2s ease;
    font-weight: bold;
    font-size: 17px;
}

ul.menu li.active {
    background-color: var(--color1);
}

ul.menu li a:hover {
    background-color: var(--menu_bg_hover);
}

/*===========================================================================*/
/* Side Nav                                                                  */
/*===========================================================================*/
.sidenav {
    height: 100%;
    width: 0;
    position: fixed;
    z-index: 1;
    top: 0;
    left: 0;
    background-color: var(--menu_bg);
    overflow-x: hidden;
    transition: 0.5s;
    padding-top: 60px;
    box-shadow: 2px 0px 4px #aaaaaa;
}

.sidenav a {
    padding: 4px 4px 4px 32px;
    text-decoration: none;
    display: block;
    transition: all 0.2s ease;
    color: white;
    font-weight: bold;
}

.sidenav a:hover, .offcanvas a:focus{
      color: #f1f1f1;
      background-color: var(--menu_bg_hover);
}

.sidenav .closebtn {
    position: absolute;
    top: 0;
    right: 25px;
    margin-left: 50px;
}


/*===========================================================================*/
/* Panel                                                                     */
/*===========================================================================*/
.panel {
    border: 1px solid #555;
    min-width: 300px;
    float: left;
    margin: 5px;
}

.panel-heading {
    background-color: var(--color1);
    color: #fff;
    font-weight: bold;
}

/*===========================================================================*/
/* Grid                                                                      */
/*===========================================================================*/
.grid {
    display: grid;
    grid-gap: 7px;
	grid-template-columns: repeat(auto-fill, minmax(220px, 1fr) ) ;
	color: #444;
}

.grid-background {
    /* background-image: url("https://wallpaperscraft.com/image/spruce_shadow_dark_background_branch_68089_1920x1200.jpg"); */
    background-image: url("/static/imgs/bg3.jpg");
    min-height: 950px;
    padding: 0.5em;
}

.grid-box {
    background: rgba(33, 33, 33, 0.5);
	color: #EEE;
	border-radius: 3px;
	padding: 8px;
	font-size: 110%;
    height: 300px;
    border: 1px solid var(--color2);

    /* display: flex; */
    /* Vertical align: */
    /* align-items: center; */
    /* Horizontal align: */
    /* justify-content: center; */
}


.two {
    grid-column: auto / span 2;
    /* grid-row: span 2 / auto ; */
}

.grid-box a {
    color: var(--color1);
}

.button {
    background-color: var(--color1);
    color : white;
    border : none;
    text-decoration: none;
    border-radius: 2px;
    display: inline-block;
    padding: 0.5em 1.5em;
 }


.button:hover {
    background-color : var(--color3);
}


.show {
    border: 1px solid red;
}


.ripple {
  position: relative;
  overflow: hidden;
  transform: translate3d(0, 0, 0);
}
.ripple:after {
  content: "";
  display: block;
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  pointer-events: none;
  background-image: radial-gradient(circle, #000 10%, transparent 10.01%);
  background-repeat: no-repeat;
  background-position: 50%;
  transform: scale(10, 10);
  opacity: 0;
  transition: transform .5s, opacity 1s;
}
.ripple:active:after {
  transform: scale(0, 0);
  opacity: .5;
  transition: 0s;
}


/*===========================================================================*/
/* Display elements                                                          */
/*===========================================================================*/
#messages {
    font-weight: bold;
    font-size: 80%;
    background-color: #f1f1f1;
    margin-top: 45px;
}

#main {
    transition: margin-left .5s;
    margin-left: 0em;
    margin-right: 0em;
    /*margin-top: 8px;*/
    margin-top:42px;
}

#content {
    margin: 1em;
}
